==> jammo-bin_0.7.1.tar.gz: jammo-bin-0.7.1/src/chum/7-12gui/gamesmenu.c <==
/**sequencer.c is part of JamMo.
License: GPLv2, read more from COPYING

This file is for clutter based gui.
This is the sequencer.
 */
#include <tangle.h>
#include <glib-object.h>
#include "gamesmenu.h"
#include "startmenu.h"
#include "sequencer.h"
#include "../jammo.h"

#include "../jammo-game-task.h"
#include "../jammo-game-level.h"
#include "../jammo-game-level-view.h"


/*  TODO: use signal in json
//return to startmenu
static gboolean goto_startmenu(ClutterActor *actor, ClutterEvent *event, gpointer data) {
	clutter_actor_hide(gamesmenu_group);
	show_startmenu();
	return TRUE;
}*/

gboolean start_gamesmenu()
{
	printf("Starting gamesmenu\n");

	ClutterActor* mainview;

	mainview = jammo_get_actor_by_id("main-views-widget");
	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);

	clutter_actor_show (jammo_get_actor_by_id("fullsequencer-view")); //contains only templates (show works better than load_now() )
	clutter_actor_show (jammo_get_actor_by_id("gamesmenu-view"));

	return FALSE;
}

void gamesmenu_start_first_task_on_this_level(const char* levelname) {
printf("Starting level: '%s'\n",levelname);

	clutter_actor_hide(jammo_get_actor_by_id("gamesmenu-view"));
	//tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("gamesmenu-view")));

	gchar* view_name = g_strdup_printf("%s-view",levelname);
	ClutterActor* levelview = jammo_get_actor_by_id(view_name);
	g_free(view_name);
	if (levelview==NULL)
		printf("levelview '%s' was NULL\n",view_name);
	else
		printf("levelview not NULL\n");


	clutter_actor_set_name(levelview,levelname);
	start_fullsequencer_gui(levelview);

}


void start_level_composing(TangleButton* button,gpointer data) {
	gamesmenu_start_first_task_on_this_level("level1");
}

void start_level_instrument(TangleButton* button,gpointer data) {
	gamesmenu_start_first_task_on_this_level("level3");
}


gboolean on_start_button_clicked(JammoGameLevel* game_level, TangleButton* button) {
	const gchar* name;
	name = clutter_actor_get_name(CLUTTER_ACTOR(button));
	printf("name is '%s'\n",name);


	ClutterActor* mainview;
	mainview = jammo_get_actor_by_id("main-views-widget");
	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);


	jammo_game_level_start_task(game_level, name);
	clutter_actor_show(jammo_get_actor_by_id("fullsequencer-view"));

	return FALSE;
}


void all_levels_completed(JammoGameLevel* game_level) {
	g_print("MENTOR: Now you have gone through all game levels! Feel free to do whatever you want now on...\n");
}

==> jammo-bin_0.7.2.tar.gz: jammo-bin-0.7.2/src/chum/7-12gui/gamesmenu.c <==
/**sequencer.c is part of JamMo.
License: GPLv2, read more from COPYING

This file is for clutter based gui.
This is the sequencer.
 */
#include <tangle.h>
#include <glib-object.h>
#include "gamesmenu.h"
#include "startmenu.h"
#include "sequencer.h"
#include "../jammo.h"

#include "../jammo-game-task.h"
#include "../jammo-game-level.h"
#include "../jammo-game-level-view.h"


/*  TODO: use signal in json
//return to startmenu
static gboolean goto_startmenu(ClutterActor *actor, ClutterEvent *event, gpointer data) {
	clutter_actor_hide(gamesmenu_group);
	show_startmenu();
	return TRUE;
}*/

gboolean start_gamesmenu()
{
	printf("Starting gamesmenu\n");

	ClutterActor* mainview;

	mainview = jammo_get_actor_by_id("main-views-widget");
	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);

	clutter_actor_show (jammo_get_actor_by_id("fullsequencer-view")); //contains only templates (show works better than load_now() )
	clutter_actor_show (jammo_get_actor_by_id("gamesmenu-view"));

	return FALSE;
}

void gamesmenu_start_first_task_on_this_level(const char* levelname) {
printf("Starting level: '%s'\n",levelname);

	clutter_actor_hide(jammo_get_actor_by_id("gamesmenu-view"));
	//tangle_view_unload(TANGLE_VIEW(jammo_get_actor_by_id("gamesmenu-view")));

	gchar* view_name = g_strdup_printf("%s-view",levelname);
	ClutterActor* levelview = jammo_get_actor_by_id(view_name);
	g_free(view_name);
	if (levelview==NULL)
		printf("levelview '%s' was NULL\n",view_name);
	else
		printf("levelview not NULL\n");


	clutter_actor_set_name(levelview,levelname);
	start_fullsequencer_gui(levelview);

}

/*
name of button should be in format "level1".
*/
void start_level(TangleButton* button,gpointer data) {
	gamesmenu_start_first_task_on_this_level(clutter_actor_get_name(CLUTTER_ACTOR(button)));
}


gboolean on_start_button_clicked(JammoGameLevel* game_level, TangleButton* button) {
	const gchar* name;
	name = clutter_actor_get_name(CLUTTER_ACTOR(button));
	printf("name is '%s'\n",name);


	ClutterActor* mainview;
	mainview = jammo_get_actor_by_id("main-views-widget");
	clutter_container_foreach(CLUTTER_CONTAINER(mainview), CLUTTER_CALLBACK(tangle_actor_hide_animated), NULL);


	jammo_game_level_start_task(game_level, name);
	clutter_actor_show(jammo_get_actor_by_id("fullsequencer-view"));

	return FALSE;
}


void all_levels_completed(JammoGameLevel* game_level) {
	g_print("MENTOR: Now you have gone through all game levels! Feel free to do whatever you want now on...\n");
}
